#
# spec file for package python-social-auth-core
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2018 Matthias Fehring <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname social-core
# saml is optional: packages in TW and Leap not compatible
%bcond_with saml
%{?sle15_python_module_pythons}
Name:           python-social-auth-core
Version:        4.5.4
Release:        1.3
Summary:        Python Social Auth Core
License:        BSD-3-Clause
URL:            https://github.com/python-social-auth/social-core
Source:         https://github.com/python-social-auth/%{modname}/archive/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module PyJWT >= 2.7.0}
BuildRequires:  %{python_module cryptography >= 2.1.1}
BuildRequires:  %{python_module defusedxml >= 0.5.0}
BuildRequires:  %{python_module oauthlib >= 1.0.3}
BuildRequires:  %{python_module python3-openid >= 3.0.10}
BuildRequires:  %{python_module requests >= 2.9.1}
BuildRequires:  %{python_module requests-oauthlib >= 0.6.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  ca-certificates
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module httpretty >= 0.9.6}
#/SECTION
# SECTION optional requirements for tests
BuildRequires:  %{python_module python-jose >= 3.0.0}
%if %{with saml}
BuildRequires:  %{python_module lxml < 4.7}
BuildRequires:  %{python_module python3-saml >= 1.2.1}
%endif
#/SECTION
Requires:       python-PyJWT >= 2.0.0
Requires:       python-cryptography >= 2.1.1
Requires:       python-defusedxml >= 0.5.0
Requires:       python-oauthlib >= 1.0.3
Requires:       python-python3-openid >= 3.0.10
Requires:       python-requests >= 2.9.1
Requires:       python-requests-oauthlib >= 0.6.1
Recommends:     python-python-jose >= 3.0.0
BuildArch:      noarch
%python_subpackages

%description
Python Social Auth is a social authentication/registration
mechanism with support for several frameworks and auth providers.

This is the core component of the python-social-auth ecosystem. It
implements the common interface to define new authentication backends to
third party services, implement integrations with web frameworks and
storage solutions.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%if !%{with saml}
donttest+=" or test_saml"
%endif
%pytest -k "not (dummyprefix $donttest)"

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/social_core
%{python_sitelib}/social_auth_core-%{version}*-info

%changelog
* Mon Oct  7 2024 Dirk Müller <dmueller@suse.com>
- update to 4.5.4:
  * LinkedIn supports refresh token
  * SteamOpenId validation of identify URL
  * Box state redirestion
  * The `uid` is automatically converted to string in the
    pipeline
  * Mediawiki error handling
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- update to 4.5.3:
  * OpenStreetMap OAuth2
  * Etsy backend fixes
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- update to 4.5.2:
  * Updated Facebook API version to 18.0
  * Make AppleID work with multiple identifiers
* Fri Dec  1 2023 David Anes <david.anes@suse.com>
- Update to 4.5.1
  - OpenID Connect skips at_hash validation when missing
  - redirect_name is now passed to backend on do_complete
  - next is preserved through SAML RelayState
  - Add Discogs backend
  - Add BitbucketDataCenterOAuth2 backend
  - Keycloak's ID_KEY is no longer configurable (it never worked)
* Mon Nov 13 2023 David Anes <david.anes@suse.com>
- Update to 4.5.0
  - Add backend for LinkedIn OpenID Connect
  - Add backend for EGI Check-in
  - Support Python 3.12 (and 3.11)
  - Add backend for the WLCG IAM testing site
  - Add ping identity OIDC backend
  - Add uffd oauth2 backend
  - Add Clever backend
  - Add Twitter OAuth2 backend
  - Add backend for e-infra.cz
  - Replace jose with pyjwt
* Tue Apr 25 2023 David Anes <david.anes@suse.com>
- Update to 4.4.2
  - Fixed Azure AD Tenant authentication with custom signing keys
  - Added CAS OIDC backend
* Thu Apr 13 2023 David Anes <david.anes@suse.com>
- Update to 4.4.1
  - Moved Facebook Limited Login to a separate module to avoid extra
    dependency
  - Update Azure AD B2C base URL to match updated endpoints
* Thu Mar 16 2023 David Anes <david.anes@suse.com>
- Update to 4.4.0
  - Backend for OpenInfra OpenID
  - Facebook Limited Login backend
  - Add support for Python 3.11
  - Removed OpenStackDevOpenId backend
  - Updated `user_data` method in `StripeOAuth2` to return `email`
    in `get_user_details`
  - Removes fixed version of `lxml`
  - Fixed OIDC crash on groups
  - Fixed Qiita users identification
  - Dropped support for TLSv1
  - Coding style improvements
* Mon Jun 13 2022 Ben Greiner <code@bnavigator.de>
- Update to 4.3.0
  * Add backend for Hashicorp Vault OIDC backend
  * Add generic OpenID Connect backend
  * Add Grafana OAuth2 backend
  * Add MusicBrainz OAuth2 backend
  * Fixed redirect state for Keycloak backend
  * Add fallback to RSA256 in OpenID Connect when alg is not set
  * Fixed Azure backend so it can be used with all Azure authority
    hosts
- Don't test extra saml for which the distro does not have the right
  packages
* Wed Apr 20 2022 pgajdos@suse.com
- python-mock is not required for build
* Wed Mar  2 2022 Matej Cepl <mcepl@suse.com>
- Add URL
* Wed Mar  2 2022 Matej Cepl <mcepl@suse.com>
- Update to 4.2.0:
  - Add fields that populate on create but not update
    SOCIAL_AUTH_IMMUTABLE_USER_FIELDS
  - Add Gitea oauth2 backend
  - Add Twitch OpenId backend
  - Add CI Logon backend
  - Add support for Python 3.10
  - Fixed Slack user identity API call with Bearer headers
  - Fixed microsoft-graph login error
  - Fixed Twitch OAuth2 backend
  - Fixed Facebook API version
  - Fixed Okta authentication URLs
  - Fixed Globus JWT signature algorithm
  - Fixed kid key rotation for OpenID Connect
  - Fixed e-mail fetching from Azure
  - Fixed vkontakte API version
  - Restricted lxml to 4.6.x to avoid problems in SAML
- Add URL
* Mon Mar 15 2021 Markéta Machová <mmachova@suse.com>
- Update to 4.1.0
  * Dropped Python 2 support from testing stack
  * Discourse backend
  * Osso backend
  * Use strategies as interface to fetch backends
  * PayPal backend
  * Fence OIDC-based backend
- Drop merged resolve_depreciations.patch, remove-unittest2.patch
  and saml_config.json
* Tue Dec 22 2020 Matej Cepl <mcepl@suse.com>
- Update to 3.4.0:
  - Added
  - Zoom backend
  - Changed
  - Directly use access_token in Azure Tenant backend
  - Support Apple JWT audience
  - Update partial session cleanup to remove old token from session
    too
  - Fetch user email in Okta integration
  - Improve Python 3.9 compatibility
  - Send proxies in request
  - Improve error handling in Apple backend
* Mon Aug 17 2020 Matej Cepl <mcepl@suse.com>
- Add resolve_depreciations.patch to clean deprecation warnings
  (gh#python-social-auth/social-core#500)
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Apr 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.3:
  * Reverted PR #388 due to dependency license incompatibility
  * Updated package upload method to use twine
  * Updated list of default user protected fields to include admin flags and password
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 3.3.0
  [#]## Added
  - Okta backend
  - Support for SAML Single Logout
  - SimpleLogin backend
  - SurveyMonkey backend
  - HubSpot backend
  - MRG backend
  - Sign in with Apple backend
  - Allow ignoring of default protected user fields with option `SOCIAL_AUTH_NO_DEFAULT_PROTECTED_USER_FIELDS`
  - Support for users field names mapping
  - Added GithubAppAuth backend
  [#]## Changed
  - Add refresh token to Strava backend, change username and remove email
  - Update test runner to PyTest
  - Add python 3.7 CI target
  - Send User-Agent header on Untappd backend
  - Updated Naver API support from XML to JSON format
  - Use `unidecode` to cleanup usernames from unicode characters
  - Update Twitch API support from v3 to v5
  - Properly setup `pytest` version for Python2 and Python3
  - Fix some spelling mistakes in docstrings
  - Fix old fields from FIELDS_STORED_IN_SESSION persisting in session
  - Github: pass access token in a header instead of in a query parameter.
  - Update Kakao API support from v1 to v2
  - Update Twitch API support to v5
  - Updated Patreon API support from v1 to v2 per issue #307
  - Fix `user_details` in user pipeline to allow model attributes to be updated
  - Updated Atlassian API urls
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.0:
  * Cognito backend
  * OpenStack (openstackid and openstackid-dev) backends
  * Many fixes to all existing Backends to match up upstream projects
* Thu Apr 11 2019 John Vandenberg <jayvdb@gmail.com>
- Remove build dependency on unittest2, as this was also a missing
  runtime dependency on both Python 2 and 3 as the tests are
  distributed in the runtime package, and are used by the test suite
  of other packages.
  * Add patch remove-unittest2.patch
- Suggest python3-saml dependency for both Python 2 & 3, and
  activate the SAML tests, adding missing saml_config.json for tests.
  Not recommended due to dependency chain including libxmlsec,
  which at the moment is unsupported v1.2.20
- Add README.md to %%doc
* Wed Apr  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Lower down PyJWT dependency the higher is not really needed
* Tue Apr  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.0:
  * Universe Ticketing backend
  * Auth0.com authentication backend
  * Update Bungie backend dropping any Django reference
  * Enable and fix JWT related tests
  * Remove PyPy support from Tox
  * Drop support for Python 3.4 in Tox
  * Allow to override JWT decode options in Open ID Connect base backend
  * Pass access token via Authorization header to Google user data url
  * Updated user_data method in AzureADOAuth2 to return access_token if id_token is not present in response
  * Updated Azure B2C to extract first email from list if it's a list
  * Replace deprecated Google+ API usage with https://www.googleapis.com/oauth2/v3/userinfo
  * Updated Azure Tenant to fix Nonetype error
  * Updated comment denoting incorrect setting name
  * Yandex: do not fail when no email is present
  * Mediawiki: do not fail when no email is present
  * Mediawiki: enhance get_user_details to return more details
* Fri Nov 30 2018 Matthias Fehring <buschmann23@opensuse.org>
- Update to version 2.0.0
  + Added Telegram authentication backend
  + Added Keycloak backend with premilinary OAuth2 support
  + Added Globus OpenId Connect backend
  + Added Discord OAuth2 backend
  + Added SciStarter OAuth2 backend
  + Added Flat OAuth2 backend
  + Added ELIXIR OpenId Connect backend
  + Added Atlassian OAuth2 backend
  + GitHub backend now uses state parameter instead of redirect_state
  + Correct setting name on AzureAD Tenant backend
  + Introduce access token expired threshold of 5 seconds by default
  + Delete partial token from session if still present
  + Use userPrincipalName to set username and email accordingly
  + Send authorization headers to Kakao OAuth2, properly fill user details
  + LINE API update to v2.1
  + Use unitest2 with Python 3
  + Update Slack backend to use computed usename on teams setups
  + Enforce unicode_literals on Slack backend
  + Update ORCID backend to support Member API
  + Updated Pixelpin backend to use the new OpenId Connect service
  + Update sanitize_redirect to invalidate redirects like ///evil.com
  + Update Coinbase API endpoint
  + Dropped Python 3.3 support
  + Updated Weixin backend to use urlencode from six
  + Updated Google+ backend to properly process requests with id_token
  + Updated OpenId connect dependencies
- Require python3 3.4.0 or newer to build and run
* Wed Aug  1 2018 tchvatal@suse.com
- Format with spec-cleaner
- Run the tests with %%python_expand rather than %%python_exec
* Fri Jul 27 2018 jengelh@inai.de
- Ensure neutrality of description. Address punctuation issues.
* Wed Jul 25 2018 sean.marlow@suse.com
- Move license in spec.
- Drop devel module dependency.
- Remove conditionals from buildRequirements.
* Tue Feb 20 2018 buschmann23@opensuse.org
- update to version 1.7.0
  + Update EvenOnline token expiration key
  + Update OpenStreetMap URL to https
  + Fix LinkedIn backend to send the oauth_token as Authorization header
  + Fixed extra_data update to use the alias as key too
  + Make signed_request optional in Facebook App OAuth2 backend
  + Support string and lists on SAML permanent id value
  + Correct sending params sending on GET access-token retrieval case
  + Ensure b2c policy name check
  + Use extras_requrie to specify python specific version dependencies
  + Added support for AzureAD B2C OAuth2
  + Added LinkedIn Mobile OAuth2 backend
- spec file changes
  + do not include README.md in files list because it does not
    contain any relevant information
* Fri Dec 29 2017 buschmann23@opensuse.org
- update to version 1.6.0
  + Fix coinbase backend to use api v2
  + Default REDIRECT_STATE to False in FacebookOAuth2 backend
  + Add revoke token url for Coinbase OAuth2 backend
  + Fix LinkedIn backend to send oauth_token as request header
  + Make partial step decorator handle arguments
  + Added support for ChatWork OAuth2 backend
- spec file changes
  + put explicit py2 and py3 buildrequires into ifpython codeblocks
* Sat Dec 16 2017 buschmann23@opensuse.org
- improve spec file summary and description
* Wed Nov 15 2017 buschmann23@opensuse.org
- update to version 1.5.0
  + Fix using the entire SAML2 nameid string
  + Prevent timing attacks against state token
  + Updated GitLab API version to v4
  + Enforce UTC when calculating access token expiration time
  + Cleanup user attributes update from social details
  + Send authorization header on Reddit auth
  + Added support for tenant for Azure AD backend
  + Added JWT validation for Azure AD backend
  + Added support for Bungie.net OAuth2 backend
  + Added support for Eventbrite OAuth2 backend
  + Added support for OpenShift OAuth2 backend
  + Added support for Microsoft Graph OAuth2 backend
- spec file changes
  + use python_expand for nosetests
  + add CHANGELOG.md to docs
  + update project url
* Tue Oct 24 2017 buschmann23@opensuse.org
- fix requirements for python-openid
* Tue Oct 24 2017 buschmann23@opensuse.org
- convert into single spec
* Thu Aug 10 2017 buschmann23@opensuse.org
- update to version 1.4.0
  + Fix path in import BaseOAuth2 for Monzo
  + Fix auth header formatting problem for Fitbit OAuth2
  + Raise AuthForbidden when provider returns 401.
  + Update Facebook API to version 2.9
  + Speed up authorization process for VKAppOAuth2
  + Apply same sanitization as on connect to disconnect.
  + Disable redirect_state usage on Disqus backend
  + Added Udata OAuth2 backend
  + Added ORCID backend
  + Added feature to get all extra data from backend through
    GET_ALL_EXTRA_DATA boolean flag.
  + Added Patreon provider
- update to version 1.3.0
  + Use extra_data method when refreshing an access_token, ensure that
    auth-time is updated then
  + Added 500px OAuth1 backend
  + Added Monzo OAuth2 backend
  + Added get_access_token method that will refresh if expired
  + Updated email validation to pass the partial pipeline token if
    given.
  + Prefer passed parameters in authenticate method
  + Properly discard already used verification codes
  + Save SAML attributes in extra_data
  + Note id_token in GooglePlusAuth's AuthMissingParameter
